"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createAllowOriginHeader = void 0;
var type_guards_1 = require("../type-guards");
var logger_1 = require("../logger");
function matches(str) {
    return function (match) {
        if ((0, type_guards_1.isString)(match)) {
            return match === str;
        }
        return match.test(str);
    };
}
function originMatches(origin, allowedOrigins) {
    return allowedOrigins.some(matches(origin));
}
function createAllowOriginHeader(headers, allowedOrigins) {
    var _a, _b;
    (0, logger_1.logger)("Checking for allowed origins");
    if (allowedOrigins.length === 0) {
        (0, logger_1.logger)("No allowed origins set, setting wildcard *");
        return { "Access-Control-Allow-Origin": "*" };
    }
    var origin = (_b = ((_a = headers.Origin) !== null && _a !== void 0 ? _a : headers.origin)) === null || _b === void 0 ? void 0 : _b.toString();
    if (originMatches(origin, allowedOrigins)) {
        (0, logger_1.logger)("Origin matches, setting header to ".concat(origin));
        return { "Access-Control-Allow-Origin": origin, Vary: "Origin" };
    }
    (0, logger_1.logger)("Origin does not match any allowed origin, not setting header");
    return { Vary: "Origin" };
}
exports.createAllowOriginHeader = createAllowOriginHeader;
//# sourceMappingURL=createAllowOriginHeader.js.map